package com.example.mynotepad.Menu;

import android.content.Context;
import android.content.Intent;
import android.util.AttributeSet;
import android.view.View;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.example.mynotepad.MenuFeatures.AllArchivedNotes.ArchivedNotesActivity;
import com.example.mynotepad.MenuFeatures.AllNotes.AllNotesActivity;
import com.example.mynotepad.MenuFeatures.Calender.MyCalenderActivity;
import com.example.mynotepad.MenuFeatures.Information.InfoClickListener;
import com.example.mynotepad.MenuFeatures.Setting.SettingActivity;
import com.example.mynotepad.MenuFeatures.VoiceMassages.VoiceMassagesActivity;
import com.example.mynotepad.R;
import com.google.android.material.snackbar.Snackbar;

public class CustomMenu extends LinearLayout implements View.OnClickListener {
    private View rootView;
    private TextView settingTv, allNotesTv, archivedTv, calenderTv, informationTv, voiceMassagesTv;
    private ImageView img;
    private InfoClickListener infoClickListener;

    public CustomMenu(Context context) {
        super(context);
        init(context);
    }

    public CustomMenu(Context context, AttributeSet attrs) {
        super(context, attrs);
        init(context);
    }


    private void init(Context context) {
        rootView = inflate(context, R.layout.custom_menu, this);
        settingTv = findViewById(R.id.settingTxt);
        allNotesTv = findViewById(R.id.allNotesTxt);
        archivedTv = findViewById(R.id.archivedTxt);
        calenderTv = findViewById(R.id.calenderTxt);
        informationTv = findViewById(R.id.infoTxt);
        voiceMassagesTv = findViewById(R.id.voiceTxt);
        img = findViewById(R.id.imageView5);

        settingTv.setOnClickListener(this);
        allNotesTv.setOnClickListener(this);
        archivedTv.setOnClickListener(this);
        calenderTv.setOnClickListener(this);
        informationTv.setOnClickListener(this);
        voiceMassagesTv.setOnClickListener(this);
        img.setOnClickListener(this);
    }

    @Override
    public void onClick(View view) {
        if (view.getId() == settingTv.getId()) {
            showSetting();
        } else if (view.getId() == allNotesTv.getId()) {
            showAllNotes();
        } else if (view.getId() == archivedTv.getId()) {
            showArchived();
        } else if (view.getId() == calenderTv.getId()) {
            showCalender();
        } else if (view.getId() == informationTv.getId()) {
            infoClickListener.onInfoTvClicked(informationTv);
        } else if (view.getId() == voiceMassagesTv.getId()) {
            showVoiceMassages();
        } else {
            Snackbar.make(view, "this is zahra's app ;)", Snackbar.LENGTH_LONG).setAction("Action", null).show();
        }
    }

    private void showVoiceMassages() {
        Intent intent = new Intent(getContext(), VoiceMassagesActivity.class);
        getContext().startActivity(intent);
    }

    private void showCalender() {
        Intent intent = new Intent(getContext(), MyCalenderActivity.class);
        getContext().startActivity(intent);
    }

    private void showArchived() {
        Intent newIntent = new Intent(getContext(), ArchivedNotesActivity.class);
        getContext().startActivity(newIntent);
    }

    private void showSetting() {
        Intent newIntent = new Intent(getContext(), SettingActivity.class);
        getContext().startActivity(newIntent);
    }

    private void showAllNotes() {
        Intent newIntent = new Intent(getContext(), AllNotesActivity.class);
        getContext().startActivity(newIntent);
    }

    public void setInfoClickListener(InfoClickListener infoClickListener) {
        this.infoClickListener = infoClickListener;
    }
}
